@@ -198,6 +198,7 @@ module SiSU_document_structure_extract
           if t_o =~/^code\{/
             @@flag['code']=true
             @@counter=1
+            @codeblock_numbered=(t_o =~/^code\{#/) ? true : false
             h={:obj=>'code block start'}                   #introduce a counter
             t_o=SiSU_document_structure::Object_comment.new.comment(h) #t_o=SiSU_document_structure::Object_layout.new.insert(h)
           elsif t_o =~/^poem\{/
@@ -314,7 +315,7 @@ module SiSU_document_structure_extract
           if t_o =~/^\}code/
             @@flag['code']=false
             obj,tags=extract_tags(@tuned_code.join("\n"))
-            h={:obj=>obj,:tags=>tags}
+            h={:obj=>obj,:tags=>tags,:number_=>@codeblock_numbered}
             t_o=SiSU_document_structure::Object_group.new.code(h)
             @tuned_code=[]
             tuned_file << t_o
@@ -422,16 +423,14 @@ module SiSU_document_structure_extract
         h={:obj=>'Index'}
       end
       tuned_file << @pb
-      h={:obj=>'Metadata'}
-      h={:ln=>2,:obj=>'Metadata',:autonum_=>false}
+      h={:ln=>2,:obj=>'Metadata',:autonum_=>false,:ocn_=>false}
       tuned_file << SiSU_document_structure::Object_heading.new.heading_insert(h)
-      h={:ln=>4,:obj=>'SiSU Metadata, document information',:name=>'metadata',:autonum_=>false}
+      h={:ln=>4,:obj=>'SiSU Metadata, document information',:name=>'metadata',:autonum_=>false,:ocn_=>false}
       tuned_file << SiSU_document_structure::Object_heading.new.heading_insert(h)
       tuned_file << @pb
-      h={:obj=>'Manifest'}
-      h={:ln=>2,:obj=>'Manifest',:autonum_=>false}
+      h={:ln=>2,:obj=>'Manifest',:autonum_=>false,:ocn_=>false}
       tuned_file << SiSU_document_structure::Object_heading.new.heading_insert(h)
-      h={:ln=>4,:obj=>'SiSU Manifest, alternative outputs etc.',:name=>'sisu_manifest',:autonum_=>false}
+      h={:ln=>4,:obj=>'SiSU Manifest, alternative outputs etc.',:name=>'sisu_manifest',:autonum_=>false,:ocn_=>false}
       tuned_file << SiSU_document_structure::Object_heading.new.heading_insert(h)
       tuned_file
       h={:obj=>'eof'}
@@ -462,9 +461,9 @@ module SiSU_document_structure_extract
       language=l[:l]
       tr=SiSU_Translate::Source.new(@md,language)
       meta << @pb
-      h={:ln=>2,:obj=>'Metadata'}
+      h={:ln=>2,:obj=>'Metadata',:ocn_=>false}
       meta << SiSU_document_structure::Object_heading.new.heading(h)
-      h={:ln=>4,:name=>'metadata',:obj=>'Metadata',:autonum_=>false}
+      h={:ln=>4,:name=>'metadata',:obj=>'Metadata',:autonum_=>false,:ocn_=>false}
       meta << SiSU_document_structure::Object_heading.new.heading(h) #add ocnm
       s="Document Manifest @\n #{base_html}/#{@md.fn[:manifest]}"
       meta << meta_para(s)
