@@ -398,6 +398,11 @@ module SiSU_EPUB_Format
     background: #880000;
   }
 
+  tt {
+    font-family: inconsolata, andale mono, courier new, courier, monospace;
+    background-color: #eeeeee;
+  }
+
   label.ocn {
     width: 2%;
     float: right;
@@ -1026,17 +1031,22 @@ WOK
       def metadata #metadata dc
         author=if defined? @md.creator.author \
         and @md.creator.author =~/\S+/
-          %{\n    <dc:creator opf:file-as="#{@md.creator.author}" opf:role="aut">#{@md.creator.author}</dc:creator>}
+          x=@md.creator.author.gsub!(/</,'&lt;'); @md.creator.author.gsub!(/>/,'&gt;')
+          @md.creator.author.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{x}" opf:role="aut">#{x}</dc:creator>}
         else ''
         end
         illustrator=if defined? @md.creator.illustrator \
         and @md.creator.illustrator =~/\S+/
-          %{\n    <dc:creator opf:file-as="#{@md.creator.illustrator}" opf:role="ill">#{@md.creator.illustrator}</dc:creator>}
+          x=@md.creator.illustrator.gsub!(/</,'&lt;'); @md.creator.illustrator.gsub!(/>/,'&gt;')
+          @md.creator.illustrator.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{x}" opf:role="ill">#{x}</dc:creator>}
         else ''
         end
         rights=if defined? @md.rights.all \
         and @md.rights.all =~/\S+/
-          %{\n    <dc:rights>#{@md.rights.all}</dc:rights>}
+          rights=@md.rights.all.gsub(/<br>/,'<br />')
+          %{\n    <dc:rights>#{rights}</dc:rights>}
         else ''
         end
         <<WOK
@@ -1276,9 +1286,6 @@ WOK
     def head
       %{#{doc_type}
 <head>
-  <title>
-    #{@md.html_title}
-  </title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{@css.xhtml_epub}
 </head>
@@ -1308,8 +1315,9 @@ WOK
     end
     def rights
       def all
-        rights=@md.rights.all.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
-        %{<p class="small_left">Rights: #{rights}</p>}
+        rghts=@md.rights.all.gsub(/<br>/,'<br />')
+        rghts=rghts.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
+        %{<p class="small_left">Rights: #{rghts}</p>}
       end
       self
     end
@@ -1584,29 +1592,10 @@ WOK
 #{@vz.js_top}}
     end
     def toc_metadata
-      @metalink=%{./#{@md.fn[:meatadata]}}
+      @metalink=%{./#{@md.fn[:metadata]}}
       toc_metadata
     end
     def title_banner(title,subtitle,creator)
-      %{
-<div class="summary">
-  <p class="tiny">
-    #{title}
-  </p>
-  <p class="tiny">
-    #{subtitle}
-  </p>
-  <p class="tiny">
-    #{creator}
-  </p>
-  <p class="tiny">
-    copy @
-    <a href="#{@vz.url_home}">
-      #{@vz.txt_home}
-    </a>
-  </p>
-</div>
-}
     end
   end
   class Head_scroll < Head_toc
@@ -1920,7 +1909,13 @@ WOK
   </p>
 }
     end
+    def clean(txt)
+      txt.gsub!(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/,'')
+      txt.gsub!(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
+      txt
+    end
     def subtoc_lev(tag,attrib)
+      @txt=clean(@txt)
       txt=if @txt \
       and @txt =~/<\/?i>|<a\s+name="\S+?">/mi
         @txt.gsub(/<\/?i>|<a\s+name="\S+?">/mi,'') #removes name markers from subtoc, go directly to substantive text
