@@ -147,7 +147,7 @@ module SiSU_HTML_Format
     def home
       %{<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="../index.html" target="_top">
-  #{@vz.png_homepage}</a>
+  #{@vz.nav_txt_homepage}</a>
 </td>
 }
     end
@@ -198,6 +198,17 @@ module SiSU_HTML_Format
       else ''
       end
     end
+    def txt
+      txt=if @cf_defaults.cf_0 =~/[at]/
+        %{
+<td valign=bottom bgcolor=#{@vz.color_band2}>
+  <a href="#{@md.fn[:plain]}" target="_top" #{@vz.js_plaintext}>
+    #{@vz.nav_txt_plaintext}
+  </a>
+</td>}
+      else ''
+      end
+    end
     def epub
       epub=if @cf_defaults.cf_0 =~/e/
         %{
@@ -338,7 +349,7 @@ WOK
       %{<table summary="toc segment and scroll with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
   #{scroll}
-  #{wgt.seg(@vz.nav_txt_toc_link)}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
+  #{wgt.seg(@vz.nav_txt_toc_link)}#{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
   #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
   #{wgt.search}
@@ -355,7 +366,7 @@ WOK
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
   #{seg}
-  #{wgt.scroll(@vz.nav_txt_doc_link)}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
+  #{wgt.scroll(@vz.nav_txt_doc_link)}#{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
 <td align="center" bgcolor=#{@vz.color_band2}>
   #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
@@ -407,7 +418,7 @@ WOK
 #{@vz.table_close}}
       end
     end
-    def links_guide_vertical_open #???
+    def links_guide_vertical_open
       url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="vertical_links">
@@ -427,7 +438,7 @@ WOK
   </li>
 <!- quick ref -!>}
     end
-    def links_guide_horizontal_open #???
+    def links_guide_horizontal_open
       url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="horizontal_links">
@@ -455,15 +466,10 @@ WOK
     def links_guide_close
       insert=''
       insert=if @md.sfx_src =~/s?/
-        link='http://www.jus.uio.no/sisu'                  #get from defaults
-        url='www.jus.uio.no/sisu'
+        link='http://sisudoc.org'                          #get from defaults
+        url='sisudoc.org'
         name='SiSU electronic documents'                   #get from defaults
-        #name='SiSU electronic documents/books'            #get from defaults
-        insert= %{  <li class="refbold">
-    <a href="#{link}" alt="#{name}" target="_top">
-      #{name}
-    </a>
-  </li>
+        insert= %{
   <li class="ref">
     <a href="#{link}" alt="#{name}" target="_top">
       #{url}
@@ -736,7 +742,7 @@ WOK
 <tr>
   #{wgt.seg(@vz.nav_txt_toc_link)}
   #{wgt.scroll(@vz.nav_txt_doc_link)}
-  #{wgt.epub}#{wgt.pdf}#{wgt.odf}
+  #{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
 <td align="center" bgcolor=#{@vz.color_band2}>
   #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
@@ -749,7 +755,7 @@ WOK
 <tr>
   #{wgt.seg(@vz.nav_txt_toc_link)}
   #{wgt.scroll(@vz.nav_txt_doc_link)}
-  #{wgt.epub}#{wgt.pdf}#{wgt.odf}
+  #{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
 <td align="center" bgcolor=#{@vz.color_band2}>
   #{wgt.manifest}
   #{wgt.search}
@@ -1263,7 +1269,13 @@ WOK
   </p>
 }
     end
+    def clean(txt)
+      txt.gsub!(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/,'')
+      txt.gsub!(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
+      txt
+    end
     def subtoc_lev(tag,attrib)
+      @txt=clean(@txt)
       txt=if @txt \
       and @txt =~/<\/?i>|<a\s+name="\S+?">/mi
         @txt.gsub(/<\/?i>|<a\s+name="\S+?">/mi,'') #removes name markers from subtoc, go directly to substantive text
