@@ -298,6 +298,8 @@ WOK
             "#{Px[:cite_o]}\\1#{Px[:cite_c]}")
           dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,
             "#{Px[:strike_o]}\\1#{Px[:strike_c]}")
+          dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,
+            "#{Px[:monospace_o]}\\1#{Px[:monospace_c]}")
           unless dob.is=='code'
             dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/,'\1')
             dob.obj.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1')
