@@ -213,12 +213,13 @@ module SiSU_TeX_Pdf
       dob.tmp.gsub!(/(?:\\begin\{bfseries\}|\\begin\{itshape\})(.+?)(?:\\end\{bfseries\}|\\end\{itshape\})/m,'\1')
       cont_ln=dob.tmp.dup
       cont_ln.gsub!(@@tex_pattern_margin_number,'')
+      clearp=(dob.lv =~/B/ && dob.obj =='Metadata') ? "\\clearpage\n" : ''
       if dob.tmp =~/\\[Ff]ootnote/ #and dob =~/^[1-6]#{Tex[:tilde]}/ # removing footnotes from headings!
         cont_ln.gsub!(/\s*\\footnote\[\d+\]\{%\n .+? \}\s*/,' ')
         cont_ln.gsub!(/\s*\\Footnote[A]\{[*+]+\d*\}\{%\n .+? \}\s*/,' ')
       end
       dob.tmp.gsub!(/^(.*)\n?$/m,
-        "\\part*{\\1}
+        "#{clearp}\\part*{\\1}
 \\addcontentsline{toc}{section}{#{cont_ln}}
 \\markboth{#{title}}\n")
       dob
@@ -294,7 +295,27 @@ module SiSU_TeX_Pdf
       when /8/; '70mm'
       when /9/; '80mm'
       end
-      "\\begin{ParagraphIndent}{#{indent}}#{@dob.tmp} \\end{ParagraphIndent}}" #"\\begin{ParagraphIndent}{#{indent}}#{@dob.tmp}\\end{ParagraphIndent}}"
+      "\\begin{ParagraphIndent}{#{indent}}#{@dob.tmp} \\end{ParagraphIndent}}"
+    end
+    def bullet
+      blt=if @dob.indent
+        indent=case @dob.indent
+        when /1/; '0em'
+        when /2/; '1.0em'
+        when /3/; '2.0em'
+        when /4/; '3.0em'
+        when /5/; '4.0em'
+        when /6/; '5.0em'
+        when /7/; '6.0em'
+        when /8/; '7.0em'
+        when /9/; '8.0em'
+        else      '-1.0em'
+        end
+        "\\begin{Bullet}{#{indent}}$\\txtbullet$\\hspace{\\enspace}#{@dob.tmp}\\end{Bullet}"
+      else
+        "\\begin{Bullet}{-5mm}$\\txtbullet$\\hspace{\\enspace}#{@dob.tmp}\\end{Bullet}"
+      end
+      blt
     end
     def symbol_graphic
       dir=SiSU_Env::Info_env.new(@md.fns)
@@ -338,7 +359,7 @@ module SiSU_TeX_Pdf
         image=z[/(\S+?\.(?:png|jpg|gif)\b)/m]
         image.gsub!(/\\/,'')
         width=if z =~ /\d+x\d*/
-          w=(z[/(\d+)x\d*/,1]).to_i
+          w=(z[/\s(\d+)x\d*/,1]).to_i
           w*0.8
         else '100' #revisit, is bug for small images/icons
         end
@@ -497,7 +518,7 @@ module SiSU_TeX_Pdf
             and images_hash[ps]=~/\s+\d+x\d+(\s+|\s*#{Mx[:lnk_c]})/m
               image,x,y=z.scan(/\S+/)
               image.gsub!(/\\/,'')
-              w=((z =~/(\d+)x\d*/) ? z[/(\d+)x\d*/,1] : 200)
+              w=((z =~/\s(\d+)x\d*/) ? z[/\s(\d+)x\d*/,1] : 200)
               width={}
               width['a4'] =     ((w.to_i > @dm['a4'])     ? @dm['a4'] :     w)
               width['letter'] = ((w.to_i > @dm['letter']) ? @dm['letter'] : w)
@@ -583,6 +604,7 @@ module SiSU_TeX_Pdf
     end
   end
   class Format_head
+    require "#{SiSU_lib}/i18n"                         # defaults.rb
     def initialize(md,t_o)
       @md,@t_o=md,t_o
       @env=SiSU_Env::Info_env.new(@md.fns)
@@ -600,47 +622,16 @@ module SiSU_TeX_Pdf
       @brace_url=SiSU_Viz::Skin.new.url_decoration
       @tex2pdf=@@tex3pdf ||=SiSU_Env::System_call.new.tex2pdf_engine
       @ps=@txt if @txt=~/(?:a4|letter|legal|book|a5|b5)/i
-    end
-    def language
-      @lang=if @md.language[:code]
-        case @md.language[:code]
-        when 'en'; 'english'
-        when 'us'; 'USenglish' # depreciated, see iso-639-2
-        when 'fr'; 'french'
-        when 'de'; 'ngerman'
-        when 'it'; 'italian'
-        when 'es'; 'spanish'
-        when 'pt'; 'portuges'
-        #when 'br'; 'brazilian' # depreciated, see iso-639-2
-        when 'sv'; 'swedish'
-        when 'da'; 'danish'
-        when 'fi'; 'finnish'
-        when 'no'; 'norske,nynorsk'
-        when 'is'; 'icelandic'
-        when 'nl'; 'dutch'
-        when 'et'; 'estonian'
-        when 'hu'; 'magyar'
-        when 'pl'; 'polish'
-        when 'ro'; 'romanian'
-        when 'ru'; 'russian'
-        when 'gl'; 'greek'
-        when 'uk'; 'ukrainian'
-        when 'tr'; 'turkish'
-        when 'sk'; 'slovak'
-        when 'sl'; 'slovenian'
-        when 'hr'; 'croatian'
-        when 'cs'; 'czech'
-        when 'bg'; 'bulgarian'
-        else       'english'
-        end
-      else         'english'
-      end
+      @lang ||=SiSU_i18n::Language.new(@md)
     end
     def tex_head_lang #babel 18n
-      language
-      lang=if @lang =~/^(?:en)$/; @lang
-      else "#{@lang},english"
-      end
+      lang_char_arr=@md.i18n
+      mainlang_char=lang_char_arr.slice(0)
+      mainlang=@lang.tex_name(mainlang_char)
+      otherlang=[]
+      lang_char_arr.slice(1..9).each { |ch| otherlang << @lang.tex_name(ch) }
+      otherlang=otherlang.join(',')
+      { :mainlang=>mainlang, :otherlang=>otherlang }
     end
     def tex_head_encode
       texpdf_font=if defined? @md.make.texpdf_font \
@@ -653,8 +644,8 @@ module SiSU_TeX_Pdf
       when /xe/
         <<WOK
 \\usepackage{polyglossia, ucs, fontspec, xltxtra, xunicode}
-\\setmainlanguage{#{tex_head_lang}}
-\\setotherlanguage{english}
+\\setmainlanguage{#{tex_head_lang[:mainlang]}}
+\\setotherlanguage{#{tex_head_lang[:otherlang]}}
 \\setmainfont{#{texpdf_font}}
 WOK
       when /pdf/
@@ -750,7 +741,7 @@ WOK
         when /a5/i
           d[:papertype],d[:fontsize]='a5paper','11pt'
           d[:oddsidemargin],d[:evensidemargin],d[:topmargin]='-4mm','-4mm','-36pt'
-          d[:headheight],d[:headsep],d[:columnsep]='8pt','12pt',''
+          d[:headheight],d[:headsep],d[:columnsep]='11pt','12pt',''
           d[:marginparsep],d[:marginparwidth]='4mm','6mm'
           d[:textheight],d[:textwidth]=@tx.a5.portrait.h,@tx.a5.portrait.w
         else           #default currently A4
@@ -892,7 +883,7 @@ WOK
     end
     def document_head_with_orientation
       endnotes=("\\usepackage{endnotes}" if @txt =~/endnotes?/)||'' #not implemented see also def endnotes
-      language
+      @lang.tex_name(@md.i18n[0])
       <<WOK
 #{tex_head_paper}
 #{tex_head_encode}
@@ -917,6 +908,17 @@ WOK
 \\item[]
 }
 {\\end{list}}
+\\newenvironment{Bullet}[1]%
+{
+\\begin{list}{}{%
+\\setlength\\topsep{0pt}%
+\\addtolength{\\leftmargin}{#1}
+\\itemindent=-1em
+\\setlength\\parsep{0pt plus 1pt}%
+}
+\\item[]
+}
+{\\end{list}}
 \\usepackage{fancyhdr}
 \\lhead{}
 \\renewcommand{\\part}{\\\@startsection
@@ -944,7 +946,7 @@ WOK
   {-\\baselineskip}{0.5\\baselineskip}%
   {\\normalfont\\normalsize\\itshape\\raggedright}}
 % \\makeatother
-\\selectlanguage{#{language}}
+\\selectlanguage{#{@lang.tex_name(@md.i18n[0])}}
 WOK
     end
     def a4generic
@@ -962,12 +964,20 @@ WOK
       para_array=[]
       str=if word
         word.each do |w| # _ - / # | : ! ^ ~
+          if w !~/http:/ \
+          and w=~/\/\S+?\// \
+          and w.length > 6
+            w.gsub!(/([_.\/])/,'\1\-')
+          end
           w.gsub!(/#{Mx[:gl_o]}#lt#{Mx[:gl_c]}/,'<'); w.gsub!(/#{Mx[:gl_o]}#gt#{Mx[:gl_c]}/,'>')
           w.gsub!(/[\\]?~/,'<=tilde>')
           w.gsub!(/[#{Mx[:br_line]}#{Mx[:br_paragraph]}]/,' \newline ') #watch
           w.gsub!(/#{Mx[:gl_o]}#(?:126|152)#{Mx[:gl_c]}/,'<=tilde>') #126 usual
           w.gsub!(/\\?\||#{Mx[:gl_o]}#124#{Mx[:gl_c]}/,'<=pipe>') #unless is=='code' #unless w=~/<~\d+;(?:[ohmu]|[0-6]:)\d+;\w\d+>/ # | SiSU not really special sisu character but done, also LaTeX
-          w.gsub!(/\#/,'<=hash>') unless w =~/#{Mx[:rel_o]}/
+          if w !~/#{Mx[:rel_o]}/ \
+          and w !~/#{Mx[:gl_o]}#/
+            w.gsub!(/\#/,'<=hash>')
+          end
           para_array << w
         end
         str=para_array.join(' ')
@@ -988,7 +998,8 @@ WOK
       str.gsub!(/#{Mx[:gl_o]}#(?:126|152)#{Mx[:gl_c]}/,'<=tilde>')                                 # ~ SiSU special character also LaTeX
       str.gsub!(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'\#')                                               # # SiSU special character also LaTeX
       str.gsub!(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!')                                                # ! SiSU not really special sisu character but done, also LaTeX
-      str.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')                                                # * should you wish to escape astrisk e.g. describing \*{bold}*
+      str.gsub!(/(^|\s)\*\s/,'\1\asterisk ')                                                       # * should you wish to escape astrisk e.g. describing \*{bold}*
+      str.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'\*')                                               # * should you wish to escape astrisk e.g. describing \*{bold}*
       str.gsub!(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-')                                                # - SiSU special character also LaTeX
       str.gsub!(/#{Mx[:gl_o]}#043#{Mx[:gl_c]}/,'+')                                                # + SiSU special character also LaTeX
       str.gsub!(/#{Mx[:gl_o]}#044#{Mx[:gl_c]}/,',')                                                # + SiSU special character also LaTeX
@@ -1060,6 +1071,7 @@ WOK
       str.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'\sout{\1}') # ulem
       str.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,"\$^{\\textrm{\\1}}\$")
       str.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,"\$_{\\textrm{\\1}}\$")
+      str.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\begin{monosp}\1\end{monosp}')
       unless is=='code'
         str.gsub!(/"(.+?)"/,'“\1”')  # quote marks / quotations open & close " need condition exclude for code
         str.gsub!(/\s+"/,' “')                                # open "
@@ -1191,12 +1203,16 @@ WOK
         end
       else ''
       end
-      "\\lfoot[\\textrm{\\thepage}]{\\tiny \\href{#{@vz.url_sisu}}{#{@vz.txt_signature}}#{base_prog_txt}}\n" +
+      "\\lfoot[\\textrm{\\thepage}]{\\tiny \\href{#{@vz.url_footer_signature}}{#{@vz.txt_signature}}#{base_prog_txt}}\n" +
       "\\cfoot[\\href{#{@vz.url_home}}{#{@vz.url_txt}}]{\\href{#{@vz.url_home}}{#{@vz.url_txt}}}\n" +
       "\\rfoot[\\tiny \\href{#{@vz.url_sisu}}{#{@vz.txt_signature}}]{\\textrm{\\thepage}}\n"
     end
     def site
-      "\\href{#{@vz.url_home}}{#{@vz.url_txt}}"
+      if not @vz.url_home.empty? \
+      and not @vz.url_txt.empty?
+        "\n\\date{\\begin{footnotesize} copy @ \\href{#{@vz.url_home}}{#{@vz.url_txt}} \\end{footnotesize}}"
+      else ''
+      end
     end
     def sitename                                                               #owners site, eg freeculture, free.for.all, gutenberg etc.
       "\\href{#{@vz.url_home}}{#{@vz.txt_home}}"
